==> am_mod_lbr_0_3.tar.gz: am_mod_lbr_0_3/components/lbr/config/lbr.config.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


// LIBRARY PERMISSIONS
// set
$library_config['resource']['set']['allow_export'] = 		1;
// page
$library_config['resource']['page']['locked'] = 			1;
// contributors
$library_config['resource']['user']['allow_revisioning'] = 		1;
$library_config['resource']['user']['manage_participants'] = 	2;
$library_config['resource']['user']['manage_pages'] = 			4;
$library_config['resource']['user']['allow_invite'] = 			8;

// set the default permissions for new registrants
$library_config['default_participation_permission'] = 		0;


// files
$library_config['default_file_allocation'] = 				500000000; // 20kb


// set type
$library_config['type']['open'] = 							1; // invitation only
$library_config['type']['approved'] = 						2; // registration approval
$library_config['type']['invitation'] = 					3; // auto registration
$library_config['type']['membership_type'] = 				4; // membership type access only


// publishing levels
$library_config['level']['registered'] = 					4;
$library_config['level']['public'] = 						16;


// library page status
$library_config['status']['live'] = 						1;
$library_config['status']['archive'] = 						2;


// library participant status
$library_config['user']['status']['barred'] = 				1;
$library_config['user']['status']['pending'] = 				2;
$library_config['user']['status']['active'] = 				3;
$library_config['user']['status']['hold'] = 				4;
$library_config['user']['status']['invite'] = 				5;


// library roles
$library_config['role']['editor'] = 						1;




// STATISTIC CONFIGURATION ----------------------------------------------
$library_config['statistic']['total_revisions'] = 			1;
$library_config['statistic']['total_comments'] = 			2;
$library_config['statistic']['total_set_comment'] =			3;


// TAG TYPE CONFIGURATION
$library_config['tag']['lbr']['library'] = 					1;
$library_config['tag']['lbr']['page'] = 					2;

?>

==> am_mod_lbr_0_5.tar.gz: am_mod_lbr_0_5/components/lbr/config/lbr.config.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


// LIBRARY PERMISSIONS
// set
$library_config['resource']['set']['allow_export'] = 		1;
// page
$library_config['resource']['page']['locked'] = 			1;
// contributors
$library_config['resource']['user']['allow_revisioning'] = 		1;
$library_config['resource']['user']['manage_participants'] = 	2;
$library_config['resource']['user']['manage_pages'] = 			4;
$library_config['resource']['user']['allow_invite'] = 			8;

// set the default permissions for new registrants
$library_config['default_participation_permission'] = 		0;


// files
$library_config['default_file_allocation'] = 				500000000; // 20kb


// set type
$library_config['type']['open'] = 							1; // auto registration
$library_config['type']['approved'] = 						2; // registration approval
$library_config['type']['invitation'] = 					3; // invitation only
$library_config['type']['membership_type'] = 				4; // membership type access only


// publishing levels
$library_config['level']['registered'] = 					4;
$library_config['level']['public'] = 						16;


// library page status
$library_config['status']['live'] = 						1;
$library_config['status']['archive'] = 						2;


// library roles
$library_config['role']['editor'] = 						1;




// STATISTIC CONFIGURATION ----------------------------------------------
$library_config['statistic']['total_revisions'] = 			1;
$library_config['statistic']['total_comments'] = 			2;
$library_config['statistic']['total_set_comment'] =			3;


// TAG TYPE CONFIGURATION
$library_config['tag']['lbr']['library'] = 					1;
$library_config['tag']['lbr']['page'] = 					2;

?>
